@@ -4,6 +4,8 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
+library(admiraldev)
+
 ## ---- message=FALSE, warning=FALSE--------------------------------------------
 library(admiral)
 library(dplyr)
@@ -16,6 +18,10 @@ data("admiral_adsl")
 ae <- admiral_ae
 adsl <- admiral_adsl
 
+## ----echo = FALSE-------------------------------------------------------------
+ae <- filter(ae, USUBJID %in% c("01-701-1015", "01-701-1023", "01-703-1086", "01-703-1096", "01-707-1037", "01-716-1024"))
+
+
 ## ----eval=TRUE----------------------------------------------------------------
 
 adsl_vars <- vars(TRTSDT, TRTEDT, TRT01A, TRT01P, DTHDT, EOSDT)
@@ -41,13 +47,13 @@ adae <- adae %>%
   derive_vars_dtm(
     dtc = AESTDTC,
     new_vars_prefix = "AST",
-    date_imputation = "first",
-    time_imputation = "first",
+    highest_imputation = "M",
     min_dates = vars(TRTSDT)
   ) %>%
   derive_vars_dtm(
     dtc = AEENDTC,
     new_vars_prefix = "AEN",
+    highest_imputation = "M",
     date_imputation = "last",
     time_imputation = "last",
     max_dates = vars(DTHDT, EOSDT)
@@ -125,12 +131,18 @@ count(adae, TRTP, TRTA, TRT01P, TRT01A)
 
 ## ----eval=TRUE----------------------------------------------------------------
 data(ex_single)
+ex_single <- derive_vars_dtm(
+  ex_single,
+  dtc = EXSTDTC,
+  new_vars_prefix = "EXST",
+  flag_imputation = "none"
+)
 adae <- adae %>%
   derive_var_last_dose_date(
     ex_single,
     filter_ex = (EXDOSE > 0 | (EXDOSE == 0 & grepl("PLACEBO", EXTRT))) &
-      nchar(EXENDTC) >= 10,
-    dose_date = EXSTDTC,
+      !is.na(EXSTDTM),
+    dose_date = EXSTDTM,
     analysis_date = ASTDT,
     single_dose_condition = (EXSTDTC == EXENDTC),
     new_var = LDOSEDTM,
@@ -217,12 +229,15 @@ derive_var_ontrtfl(
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  adae <- adae %>%
-#    derive_var_extreme_flag(
-#      by_vars = vars(USUBJID),
-#      order = vars(desc(ATOXGR), ASTDTM, AESEQ),
-#      new_var = AOCCIFL,
-#      filter = TRTEMFL == "Y",
-#      mode = "first"
+#    restrict_derivation(
+#      derivation = derive_var_extreme_flag,
+#      args = params(
+#        by_vars = vars(USUBJID),
+#        order = vars(desc(ATOXGR), ASTDTM, AESEQ),
+#        new_var = AOCCIFL,
+#        mode = "first"
+#      ),
+#      filter = TRTEMFL == "Y"
 #    )
 
 ## ---- eval=TRUE---------------------------------------------------------------
@@ -230,12 +245,15 @@ adae <- adae %>%
   mutate(
     ASEVN = as.integer(factor(ASEV, levels = c("MILD", "MODERATE", "SEVERE", "DEATH THREATENING")))
   ) %>%
-  derive_var_extreme_flag(
-    by_vars = vars(USUBJID),
-    order = vars(desc(ASEVN), ASTDTM, AESEQ),
-    new_var = AOCCIFL,
-    filter = TRTEMFL == "Y",
-    mode = "first"
+  restrict_derivation(
+    derivation = derive_var_extreme_flag,
+    args = params(
+      by_vars = vars(USUBJID),
+      order = vars(desc(ASEVN), ASTDTM, AESEQ),
+      new_var = AOCCIFL,
+      mode = "first"
+    ),
+    filter = TRTEMFL == "Y"
   )
 
 ## ---- eval=TRUE, echo=FALSE---------------------------------------------------
