@@ -1,15 +1,22 @@
-input_ae <- tibble::tribble(
-  ~STUDYID, ~USUBJID, ~AESEQ, ~AESTDTC,
-  "my_study", "subject1", 1, "2020-01-02",
-  "my_study", "subject1", 2, "2020-08-31",
-  "my_study", "subject1", 3, "2020-10-10",
-  "my_study", "subject2", 1, "2019-05-15",
-  "my_study", "subject2", 2, "2020-02-20",
-  "my_study", "subject3", 1, "2020-03-02",
-  "my_study", "subject4", 1, "2020-11-02"
-)
+library(tibble)
+library(dplyr)
+library(lubridate)
 
-input_ex <- tibble::tribble(
+input_ae <- tribble(
+  ~STUDYID,   ~USUBJID,   ~AESEQ, ~AESTDTC,
+  "my_study", "subject1", 1,      "2020-01-02",
+  "my_study", "subject1", 2,      "2020-08-31",
+  "my_study", "subject1", 3,      "2020-10-10",
+  "my_study", "subject2", 1,      "2019-05-15",
+  "my_study", "subject2", 2,      "2020-02-20",
+  "my_study", "subject3", 1,      "2020-03-02",
+  "my_study", "subject4", 1,      "2020-11-02"
+) %>%
+  mutate(
+    AESTDT = ymd(AESTDTC)
+  )
+
+input_ex <- tribble(
   ~STUDYID, ~USUBJID, ~EXSTDTC, ~EXENDTC, ~EXSEQ, ~EXDOSE, ~EXTRT,
   "my_study", "subject1", "2020-01-01", "2020-01-01", 1, 10, "treatment",
   "my_study", "subject1", "2020-08-29", "2020-08-29", 2, 10, "treatment",
@@ -19,10 +26,14 @@ input_ex <- tibble::tribble(
   "my_study", "subject2", "2020-01-20", "2020-01-20", 2, 0, "placebo",
   "my_study", "subject3", "2020-03-15", "2020-03-15", 1, 10, "treatment"
 ) %>%
-  mutate(EXSTDTC = as.Date(EXSTDTC), EXENDTC = as.Date(EXENDTC))
+  mutate(
+    EXSTDT = as.Date(EXSTDTC),
+    EXENDT = as.Date(EXENDTC)
+  )
 
-
-test_that("derive_var_last_dose_amt works as expected", {
+# derive_var_last_dose_amt ----
+## Test 1: works as expected ----
+test_that("derive_var_last_dose_amt Test 1: works as expected", {
   expected_output <- mutate(
     input_ae,
     LDOSE = c(10, 10, 10, NA, 0, NA, NA)
@@ -33,8 +44,8 @@ test_that("derive_var_last_dose_amt works as expected", {
     input_ex,
     filter_ex = (EXDOSE > 0) | (EXDOSE == 0 & EXTRT == "placebo"),
     by_vars = vars(STUDYID, USUBJID),
-    dose_date = EXENDTC,
-    analysis_date = AESTDTC,
+    dose_date = EXENDT,
+    analysis_date = AESTDT,
     new_var = LDOSE,
     dose_var = EXDOSE,
     single_dose_condition = (EXSTDTC == EXENDTC),
@@ -44,7 +55,8 @@ test_that("derive_var_last_dose_amt works as expected", {
   expect_dfs_equal(expected_output, res, keys = c("STUDYID", "USUBJID", "AESEQ", "AESTDTC"))
 })
 
-test_that("derive_var_last_dose_amt returns traceability vars", {
+## Test 2: returns traceability vars ----
+test_that("derive_var_last_dose_amt Test 2: returns traceability vars", {
   expected_output <- mutate(
     input_ae,
     LDOSEDOM = c("EX", "EX", "EX", NA, "EX", NA, NA),
@@ -58,8 +70,8 @@ test_that("derive_var_last_dose_amt returns traceability vars", {
     input_ex,
     filter_ex = (EXDOSE > 0) | (EXDOSE == 0 & EXTRT == "placebo"),
     by_vars = vars(STUDYID, USUBJID),
-    dose_date = EXENDTC,
-    analysis_date = AESTDTC,
+    dose_date = EXENDT,
+    analysis_date = AESTDT,
     new_var = LDOSE,
     dose_var = EXDOSE,
     single_dose_condition = (EXSTDTC == EXENDTC),
